% -*-trale-prolog-*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: le_macros.pl,v $
%%  $Revision: 1.12 $
%%      $Date: 2006/08/21 15:50:14 $
%%     Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%%    Purpose: Eine kleine Spielzeuggrammatik für die Lehre
%%   Language: Trale
%      System: TRALE 2.7.5 (release ) under Sicstus 3.10.1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

:- multifile ':='/2.
:- discontiguous ':='/2.
:- multifile if/2.
:- discontiguous if/2.
:- multifile fun/1.
:- discontiguous fun/1.
:- multifile '*>'/2.
:- discontiguous '*>'/2.


overt_le *>
 (%lexical_sign
  phon:ne_list,
  synsem:(nonloc:slash:[],
          trace:minus)).

non_rel_le *>
 (%lexical_sign
  synsem:nonloc:rel:[]).

non_overt_le *>
  (%lexical_sign
   phon:[],
   zu:minus).

trace *>
  synsem:trace:extraction_or_vm.

e_trace *>
 (%trace,
  synsem:(loc:Loc,
          nonloc:(rel:[],
                  slash:[Loc]),
          trace:extraction)).

v_trace *>
 (%trace,
  synsem:(loc:(Loc,
               cat:head:(verb,
                         initial:minus,
                         dsl:Loc)),
          nonloc:(rel:[],
                  slash:[]),
          trace:vm)).

% leere Determinierer und Nomina
empty *> synsem:nonloc:slash:[].


% normale Wörter selegieren nie DSL:local-Elemente.
% Nur über LR abgeleitete Wörter tun dies.
% Beschränkung wird gebraucht, um die Einbettung einer
% Verbspur unter ein Hilfs- oder Modalverb auszuschließen.
%
% * Der Frau den Aufsatz _v will er.
%
% Wegen der Argumentanhebung (auch von Spirits) kann man die DSL-none-Beschränkung
% nicht für die gesamte Liste machen, da das auch Sätze wie
%
% Der Frau den Aufsatz will er geben.
%
% ausschließen würde.

(overt_le,
 synsem:loc:cat:subcat:ne_list) *>
                                   synsem:loc:cat:subcat:hd:arg:loc:cat:head:dsl:none.



% Nur Verben und adjektivische Partizipien können mit zu kombiniert
% werden. Unflektierte Wörter sind immer ZU-.
% ZU ist nur ein technisches Hilfsmerkmal.
simple_word *> zu:minus.

fun list_of_non_dsl_arguments(-).
list_of_non_dsl_arguments(L) if
   when( (L=(e_list;ne_list)),
         undelayed_list_of_non_dsl_arguments(L) ).

undelayed_list_of_non_dsl_arguments([]) if true.
undelayed_list_of_non_dsl_arguments([arg:loc:cat:head:dsl:none|T]) if
   list_of_non_dsl_arguments(T).


rel_pronoun *>
 (%overt_word,
  synsem:(loc:cont:nucleus:ind:Ind,
          nonloc:rel:[Ind])).

sc_saturated_le *>
  synsem:loc:cat:subcat:[]. %list_of_spirits.  Im Lexikon kann man da spezifischer sein!

spr_saturated_le *>
  synsem:loc:cat:spr:[].


determiner_le *>
 (%saturated_le
  synsem:loc:cat:head:det).

determiner(Numerus,DType) :=
 (synsem:loc:cat:head:(num:Numerus,
                       dtype:DType)).

determiner(Case,Numerus,Genus,DType) :=
(%determiner_word,
 @determiner(Numerus,DType),
 synsem:loc:cat:head:(case:morph_case:Case,
                      gen:Genus)).


% leerer Determinator und overte Determinatoren
det(Numerus,DType,Quant) :=
 (@determiner(Numerus,DType),
  synsem:loc:cont:nucleus:Quant).

% Für Wörter und Stämme
general_determiner *> 
 (%determiner_le
  synsem:loc:(cat:head:spec:loc:cont:nucleus:Cont,
              cont:(nucleus:(Quant,
                             restind:Cont),
                    qstore:[Quant]))).

% Determinatoren mit Genus
det(Case,Numerus,Genus,DType,Quant) :=
(@determiner(Case,Numerus,Genus,DType),
 overt_determiner,
 @det(Numerus,DType,Quant)).

% Determinatoren ohne Genus
det(Case,Numerus,DType,Quant) :=
  @det(Case,Numerus,genus,DType,Quant).

mixed_det *>
  (%underived_stem,
   synsem:loc:cat:head:( dtype:(DType,
                                weak),
                         ( case:morph_case:nom,
                           gen:mas,
                           num:sg
                         ; case:morph_case:nom_or_acc,
                           gen:neu,
                           num:sg
                         )
                       ; dtype:(DType,
                                strong),
                         % either plural or singular and all the other possibilities for sg not covered in the first conjunct
                         ( num:pl
                         ; num:sg,
                           ( gen:fem
                           ; case:morph_case:gen_or_dat,
                             gen:mas_or_neu
                           ; case:morph_case:acc,
                             gen:mas
                           )
                         ))).


mixed_det(Num,Pred) :=
  (@det(Num,_Class,Pred),
   determiner_stem).


possessive *>
 (%determiner_le
  synsem:loc:(cat:head:spec:loc:cont:nucleus:(ind:NInd,
                                              restr:NRestr),
              cont:(nucleus:(ind:Ind,
                             restr:[]),
                    qstore:[(def,
                             restind:(ind:NInd,
                                      restr:[(besitzen,
                                              arg2:Ind,
                                              arg3:NInd)|NRestr]))]))).

possessive(Person,Numerus) :=
 (possessive_non_rel_pronoun, % Untertyp von mixed_det (auch für ihr???)
  synsem:loc:cont:nucleus:ind:(per:Person,
                               num:Numerus)).

possessive(Person,Numerus,Genus) :=
 (@possessive(Person,Numerus),
  synsem:loc:cont:nucleus:ind:gen:Genus).
  

% Die folgenden XP-Makros werden als Abkürzung in Valenzrahmen
% verwendet.

np :=
  (arg:loc:cat:(head:noun,
                spr:[],
                subcat:list_of_spirits)).

% Eine NP mit strukturellem Kasus
np_str :=
  (@np,
   arg:loc:cat:head:case:case_type:str).

np_lex :=
  (@np,
   arg:loc:cat:head:case:case_type:lex).

% Alle Argumente, die in Valenzrahmen spezifiziert werden, sind realized:minus.
% Es gibt auch solche, die nicht spezifiziert sondern angehoben werden.
% Diese können realized:plus oder realized:minus sein, das hängt davon ab,
% ob sie in einer Projektion im Vorfeld realisiert wurden, oder nicht.
% Die Makros np_str, np_str(Per,Num) und np_lex werden für Kasusvergabe
% und für Kongruenz genutzt. Bei ihnen darf also der REALIZED-Wert nicht
% spezifiziert sein.
argument :=
  realized:minus.

argument_np :=
  (@argument,
   @np).

np_ref :=
  (@argument_np,
   arg:
  (loc:cont:nucleus:ind:ref)).

np(Ind) :=
  (@np_ref,
   arg:
  (loc:cont:nucleus:ind:Ind)).

np_expl :=
  (@argument_np,
   @np_str,
   arg:
  (loc:cont:nucleus:ind:expl)).

% das Subjekt von Infinitiven und vom Passiv
pro_np_ref :=
 (@np_ref,
  arg:(loc:(cat:subcat:[],       % ansonsten hängt ein Constraint rum
            cont:qstore:[]),
       lex:minus),
  raised:minus).         

% für Passiv und Partizipien
blocked_np_ref :=
 (@pro_np_ref,
  realized:minus).

blocked_np_ref(Ind) :=
 (@blocked_np_ref,
  @np(Ind)).

np_str(Ind) :=
  (@np_str,
   @np(Ind)).

pro_np(Ind) :=
  (@pro_np_ref,
   @np_str(Ind)).

np_str(Per,Num) :=
  (@np_str,
   arg:loc:cont:nucleus:ind:(per:Per,
                             num:Num)).

lex(Case) :=
 (case_type:lex,
  morph_case:Case).


np(Case,Ind) :=
  (@np(Ind),
   arg:loc:cat:head:case: @lex(Case)).


np_(Per,Num) :=
 (@np,
  arg:loc:cont:nucleus:ind:(per:Per,
                            num:Num)).

no_noun :=
  (arg:loc:cat:head: @not(noun)).

nbar(Ind) :=
  loc:(cat:(head:noun,
            spr:[_],
            subcat:[]),
       cont:nucleus:ind:Ind).



pp :=
  arg:loc:cat:(head:prep,
               subcat:list_of_spirits).
pp(Ind) :=
  (@pp,
   arg:loc:cont:nucleus:ind:Ind).

pp(PForm,Case) :=
  (@pp,
   arg:loc:cat:head:(pform:PForm,
                     case:morph_case:Case)).


% Partikel über Lexikonregel selegiert
particle :=
  (@argument,
    arg:(
    loc:cat:head:part)).

% Partikel von Lexikoneinträgen nicht transparenter Verben selegiert
particle(Part) :=
  (@particle,
    arg:(
    loc:cat:head:(form:Part,
                  mod:none,
                  prd:minus),
    lex:plus)).


% alle Nomina
noun_le *>
  %lexical_sign
  synsem:loc:cat:head:noun.

% alle einfachen Nomina (ohne Argument)
det_noun *>
 (%spr_incomplete_le,
  %noun_le,
  %overt_le,
  %non_rel_le,
  %stem,
  synsem:loc:(cat:(head:case:Case,
                   spr:[loc:cat:(head:(det,
                                       case:Case,
                                       num:Numerus,
                                       gen:Genus),
                                 subcat:[] )]),
              cont:nucleus:(ind:(Ind,
                                 per:third,
                                 num:Numerus,
                                 gen:Genus),
                            restr:[arg1:Ind]))).

% Bei abgeleiteten Nomina und bei Nomina mit Argumenten
% können noch Quantoren von anderen Argumenten hinzukommen.
% Bei einfachen Nomina gibt es nur den Quantor, der direkt
% das Nomen in der Restriktion hat.
underived_simple_noun *>
 synsem:loc:(cat:spr:[loc:cont:qstore:QStore],
             cont:qstore:QStore).


noun_nominal *>
  infl:noun_infl.

underived_simple_noun_adjectival *>
 (synsem:loc:cont:nucleus:ind:gen:fem_or_mas,
  infl:adj_infl).

% Bei Mädchen, Weib usw. sind SynGenus und SemGenus
% verschieden.
noun(SynGenus,SemGenus,Relation) :=
 (underived_simple_noun_nominal,
  synsem:loc:(cat:spr:[loc:cat:head:gen:SynGenus],
              cont:nucleus:(ind:gen:SemGenus,
                            restr:[Relation]))).

% Normalerweise sind die Genus-Werte aber gleich.
% Haus
noun(Genus,Relation) :=
 @noun(Genus,Genus,Relation).


% Beamter, Verwandter
adj_noun(Relation) :=
 (underived_simple_noun_adjectival,
  synsem:loc:cont:nucleus:(ind:gen:fem_or_mas,
                           restr:[Relation])).


pronoun *>
 (%saturated_word
  synsem:loc:cont:nucleus:restr:[]).

nominal_pronoun *>
 (%noun_le,
  %pronoun
  synsem:loc:cont:qstore:[]).

pronoun(Case,Person,Numerus,Genus) :=
 (synsem:loc:(cat:head:case:morph_case:Case,
              cont:nucleus:ind:(ref,
                                per:Person,
                                num:Numerus,
                                gen:Genus))).

pers_pronoun(Case,Person,Numerus,Genus) :=
 (pers_pronoun,
  @pronoun(Case,Person,Numerus,Genus)).

% ich, du haben kein spezifiziertes Genus
pers_pronoun(Case,Person,Numerus) :=
  (@pers_pronoun(Case,Person,Numerus,genus)).


expl_pronoun *>
 (%overt_saturated_non_rel_pronoun
  synsem:loc:(cat:head:case:morph_case:nom_or_acc,
              cont:nucleus:ind:expl)).


% der, die, das
rel_pronoun(Case,Person,Numerus,Genus) :=
 (nominal_rel_pronoun,
  @pronoun(Case,Person,Numerus,Genus)).


% dessen, deren
possessive_rel_pronoun(Numerus,Genus) :=
 (possessive_rel_pronoun,
  @pronoun(_Case,third,Numerus,Genus)).



particle *>
 synsem:(loc:cat:head:part,
         lex:plus % schließt direkte Verwendung als Adjunkt aus
        ).

% anders als bei echten Adjunkten werden die Quantoren des modifizierten
% Elements nicht zu Quantoren der Partikel angehoben.
modifying_particle *>
 (synsem:loc:(cat:(head:(mod:loc:cat:head:verb,
                         subj:Subj,
                         prd:minus),
                   subcat:Subcat),
              cont:qstore:collectQStores(append(Subcat,Subj)))).


% Es muß noch weitere Klassen geben, in diesem Sprachausschnitt
% sind aber nur die folgenden zwei relevant.
% Er lacht sie an.
subj_isect_modifying_particle *>
 % modifying_particle,
 % isect_v_modifier_word,
 synsem:loc:(cat:head:(subj:[@np_str(Ind)],
                       mod:loc:cat:subcat:[@np_str]),
             cont:nucleus:arg2:arg2:Ind).

subj_less_scopal_modifying_particle *>
 %scopal_v_modifier_word,
 synsem:loc:cat:head:(subj:[],
                      mod:loc:cat:subcat:[@np_str]).


non_trans_particle *>
  synsem:loc:(cat:head:(mod:none,
                        prd:minus),
              cont:qstore:[]).

% Der Lexikoneintrag für nicht-transparente Partikelverben. Diese tragen nichts
% zur Bedeutung bei. Ihre Form wird vom regierenden Verb selegiert.
non_trans_particle(Part) :=
  (non_trans_particle,
   synsem:loc:cat:head:form:Part).


v_stem *>
 (%spr_saturated_sc_incomplete_word
  synsem:loc:(cat:(head:(verb,
                         initial:minus),
                   subcat:Subcat),
              cont:qstore:collectQStores(Subcat))).



% alle Verben außer Modalverben und `haben'
non_flip_verb_stem *>
  synsem:loc:cat:head:flip:minus.

intrans_unacc_verb *>
  synsem:loc:cat:head:da:[].


% Das designierte Argument Nicht-Unakkusativischer Verben ist das letzte
% Element in der SUBCAT-Liste. Das kann eintweder eine NP mit strukturellem
% Kasus oder ein Satzargument sein.
nerg_verb *>
  (synsem:loc:cat:(head:da:[last(Subcat)],
                   subcat:Subcat)).

intrans_nerg_verb *>
 (%non_flip_verb_stem,
  synsem:loc:(cat:subcat:Subcat,
              cont:nucleus:arg1:Ind))
       goal last(Subcat,@np_str(Ind)).

% schlafen
strict_intrans_verb *>
  synsem:loc:cat:subcat:[_].


intrans_verb(Relation) :=
 (strict_intrans_nerg_verb,
  synsem:loc:cont:nucleus:Relation).

intrans_unacc_verb *>
 (%non_flip_verb_stem,
  synsem:loc:(cat:subcat:Subcat,
              cont:nucleus:arg2:Ind))
       goal last(Subcat,@np_str(Ind)).

intrans_unacc_verb(Relation) :=
 (strict_intrans_unacc_verb,
  synsem:loc:cont:nucleus:Relation).


% denken an
np_pp_verb *> 
 (%intrans_verb,
  synsem:loc:(cat:subcat:[ @pp(Ind2), _ ],
              cont:nucleus:arg3:Ind2)).


np_pp_verb(PForm,Case,Relation) :=
 (np_pp_nerg_verb,
  synsem:loc:(cat:subcat:hd: @pp(PForm,Case),
              cont:nucleus:Relation)).


% helfen
np_np_nerg_verb *>
 (%intrans_nerg_verb,
  synsem:loc:(cat:subcat:[ @np(Ind2), _ ],
              cont:nucleus:arg2:Ind2)).

% helfen
np_np_verb(Case,Relation) :=
 (np_np_nerg_verb,
  synsem:loc:(cat:subcat:hd: @np(Case,_Ind2),
              cont:nucleus:Relation) ).

% gelingen
np_np_unacc_verb *> 
 (synsem:loc:(cat:subcat:[ @np(Ind2), @np_str(Ind1) ],
              cont:nucleus:(arg2:Ind1,
                            arg3:Ind2))).

np_np_unacc_verb(Case,Relation) :=
 (np_np_unacc_verb,
  synsem:loc:(cat:subcat:hd: @np(Case,_Ind2),
              cont:nucleus:Relation)).

% regnen
expl_np_verb *>
 (synsem:loc:cat:subcat:[ @np_expl ]).


expl_np_verb(Relation) :=
 (expl_np_verb,
  synsem:loc:cont:nucleus:Relation).

% grauen
subjless_verb *>
 (%verb,
  synsem:loc:(cat:(head:(auxf:haben,
                         da:[]),
                   subcat:[ @np(Ind) ]),
              cont:nucleus:arg2:Ind)).

% grauen, auch finit, ohne Subjekt-Verb-Kongruenz
subjlos_verb(Case,Relation) :=
 (subjless_verb,
  synsem:loc:(cat:subcat:[ @np(Case,_Ind) ],
              cont:nucleus:Relation)).


% lieben, geben
trans_verb *>
 (%verb,
  synsem:loc:(cat:subcat:append(_, [ @np_str(Ind2), @np_str(Ind1) ]),
              cont:nucleus:(arg1:Ind1,
                            arg2:Ind2))).

% lieben
strict_trans_verb *>
 (%trans_verb,
  synsem:loc:cat:subcat:[ _, _ ]).

trans_verb(Relation) :=
 (strict_trans_verb,
  synsem:loc:cont:nucleus:Relation).

% geben
ditrans_verb *>
 (%trans_verb,
  synsem:loc:(cat:subcat:[ @np(dat,Ind3), _, _ ],
              cont:nucleus:arg3:Ind3)).

ditrans_verb(Relation) :=
 (ditrans_verb,
  synsem:loc:cont:nucleus:Relation).

trans_particle_verb *>
 (%trans_verb
  synsem:loc:(cat:subcat:[ @particle, @np_str(Ind2), @np_str(Ind1) ],
              cont:nucleus:(arg1:Ind1,
                            arg2:Ind2))).

% vorschlagen
trans_verb(Relation,Particle) :=
 (trans_particle_verb,
  synsem:loc:(cat:subcat:hd: @particle(Particle),
              cont:nucleus:Relation)).



% Das sind die Beschränkungen, die nötig sind, damit
% keine eingebetteten Köpfe von komplexbildenden Prädikate angezogen werden.
%
% * weil er das Buch lesen [können wird]
%
% Komplexbildende Prädikate müssen immer direkt mit ihrem
% eingebetteten Kopf verbunden werden:
%
% weil er das Buch [[lesen können] wird]



non_complex_forming_synsem :=
  (loc:cat:subcat:list_of_spirits,
   lex:minus).

fun list_of_non_complex_forming_arguments(-).
list_of_non_complex_forming_arguments(L) if
   when( (L=(e_list;ne_list)),
         undelayed_list_of_non_complex_forming_arguments(L) ).

undelayed_list_of_non_complex_forming_arguments([]) if true.

% Mit Spirits muß man die folgenden beiden Fälle unterscheiden:
% Das Element ist noch nicht realisiert, muß also non_complex_formin sein.
undelayed_list_of_non_complex_forming_arguments([(realized:minus,
                                                  arg: @non_complex_forming_synsem)|T]) if
   list_of_non_complex_forming_arguments(T).

% Des Element ist bereits realisiert -> Es ist uns egal, wie es aussieht.
undelayed_list_of_non_complex_forming_arguments([realized:plus|T]) if
   list_of_non_complex_forming_arguments(T).


% optional kohärente Verben ziehen alle Elemente auf SUBCAT an.
optionally_coherent_le *>
  synsem:loc:cat:subcat:[@argument|list_of_non_complex_forming_arguments].


% alle Anhebungsverben, also auch die, die optional kohärent konstruieren,
% Phasenverben (beginnen), sehen, lassn und die, die obligatorisch kohärent konstruieren,
% Modalverben, Futur-Hilfsverb, Perfekt-Hilfsverb

raising_verb *>
 (%opt_coherent_le
  synsem:loc:(cat:subcat:hd:arg:loc:cont:nucleus:VCont,
              cont:nucleus:arg3:VCont)).


%% DA-Wert schließt Passivierung von Hilfsverben aus.
raising_verb *>
 synsem:loc:cat:head:da:[].


subj_raising_verb *>
 (%raising_verb,
  synsem:loc:cat:subcat:[arg:loc:cat:(head:subj:(Subj,
                                                 list_of_raised_arguments),
                                      subcat:Subcat)
                        |raise(append(Subcat,Subj))]).



coherent_le *>
  (%lexical_sign
  synsem:loc:cat:subcat:hd:arg:lex:plus).



subj_raising_verb(Relation) :=
 (subj_raising_verb,
  synsem:loc:cont:nucleus:Relation).

subj_raising_verb(GovVForm,Relation) :=
 (@subj_raising_verb(Relation),
  synsem:loc:cat:subcat:hd:arg:loc:cat:head:vform:GovVForm).


modal_verb *>
 (%bse_inf_coherent_subj_raising_verb
  synsem:loc:cat:subcat:hd:arg:loc:cat:head:flip:minus). % [ dürfen _Extraction ]     % nur für Geschwindigkeit


modal_verb(Relation) :=
 (modal_verb,
  synsem:loc:cont:nucleus:Relation).


% daß er das Lied wird haben singen müssen
modal_flip_verb(Relation) :=
 (bse_or_inf_verb_infl_lr,                % Das stimmt nicht ganz, wird im nächsten Kapitel revidiert.
  phon:Phon,
  synsem:loc:(cat:head:(vform:ppp,
                        flip:plus),
              cont:nucleus:Relation),
  zu:minus,
  dtrs:[(modal_verb,
         phon:Phon,
         infl:fk:modal)]).

futur_aux_verb *>
  synsem:loc:cont:nucleus:futur.

% gibt es nur finit
futur_aux_verb(Per,Num,TeMo) :=
 (@irregular_verb(Per,Num,TeMo),
  dtrs:[futur_aux_verb]).


% Futur, Passiv kommt im nächsten Kapitel
werden(Per-per,Num-num,TeMo-temo) :=
  @futur_aux_verb(Per,Num,TeMo).


irregular_verb(VForm) :=
 (
  ( bse_verb_infl_lr
  ; inf_verb_infl_lr
  ; ppp_verb_infl_lr
  ),
  phon:Phon,
  dtrs:[(phon:Phon,
         synsem:loc:cat:head:vform:VForm %,
        % infl:affix:irregular
        )]).


irregular_verb(Per,Num,TeMo) :=
 (irreg_fin_verb_infl_lr,
  synsem:loc:(cat:subcat:subj_verb_agreement(Per,Num),
              cont:nucleus:TeMo)).


% Passiv
passive_aux_verb *>
 (%coherent_non_flip_raising_verb
  synsem:loc:cat:subcat:hd:arg:loc:cat:head:da:[@blocked_np_ref]).

% alle Passivhilfsverben außer lassen
simple_passive_aux_verb *>
 (%coherent_non_flip_raising_verb
  synsem:loc:cat:subcat:[arg:loc:cat:subcat:Subcat|raise(Subcat)]).

agentive_passive_aux_verb *>
 (%simple_ppp_passive_aux_verb
  synsem:loc:cont:nucleus:agentive_passive).




% werden Vorgangspassiv
werden_pas(Per-per,Num-num,TeMo-temo) :=
 (@irregular_verb(Per,Num,TeMo),
  dtrs:[agentive_passive_aux_verb]).


werden(Per-per,Num-num,TeMo-temo) :=
  @werden_pas(Per,Num,TeMo).

werden_pas(VForm) :=
  (@irregular_verb(VForm),
   dtrs:[agentive_passive_aux_verb]).

werden(VForm) :=
  @werden_pas(VForm).


stative_passive_aux_verb *>
 (%simple_ppp_passive_aux_verb
  synsem:loc:cont:nucleus:stative_passive).


% sein Zustandspassiv
sein_pas(Per-per,Num-num,TeMo-temo) :=
  (@irregular_verb(Per,Num,TeMo),
  dtrs:[stative_passive_aux_verb]).


sein(Per-per,Num-num,TeMo-temo) :=
  @sein_pas(Per,Num,TeMo).

sein_pas(VForm) :=
  (@irregular_verb(VForm),
   dtrs:[stative_passive_aux_verb]).

sein(VForm) :=
  @sein_pas(VForm).




perfect_aux_verb *>
 (synsem:loc:cont:nucleus:perfect).

haben_perfect *>
 synsem:loc:cat:(head:flip:Flip,
                 subcat:hd:arg:loc:cat:head:flip:Flip).


% sein 
sein(Per-per,Num-num,TeMo-temo) :=
  (@irregular_verb(Per,Num,TeMo),
   dtrs:[sein_perfect]).

sein(VForm) :=
  (@irregular_verb(VForm),
   dtrs:[sein_perfect]).



zu_inf_verb *>
  (%non_flip_verb
   synsem:loc:cat:subcat:hd:arg:loc:cat:head:vform:inf).

% bse-Verben sind immer Anhebungsverben
bse_inf_verb *>
  (%raising_verb
   synsem:loc:cat:subcat:hd:arg:loc:cat:head:vform:bse).

ppp_inf_verb *>
  (%coherent_subj_raising_verb
   synsem:loc:cat:subcat:hd:arg:loc:cat:head:vform:ppp).



% Dativpassiv

fun promote_dat(+,-).
promote_dat(List,Promoted) if
  del((@np(dat,Ind),
       @pro_np_ref),List,Rest),
  append(Rest,[@np_str(Ind)],Promoted).

dative_passive_aux_verb *>
  (%non_flip_verb_stem
   synsem:loc:(cat:subcat:[(@argument,
                            arg:loc:(cat:subcat:Subcat,
                                     cont:nucleus:VCont))
                          |promote_dat(Subcat)],
               cont:nucleus:(passive,
                             arg3:VCont))).



% Modale Infinitive


modal_zu_inf *>
 synsem:loc:cont:nucleus:modal_rel.



sein_modal(Per-per,Num-num,TeMo-temo) :=
 (@irregular_verb(Per,Num,TeMo),
  dtrs:[modal_sein]).

sein(Per-per,Num-num,TeMo-temo) :=
  @sein_modal(Per,Num,TeMo).

sein_modal(VForm) :=
  (@irregular_verb(VForm),
   dtrs:[modal_sein]).

sein(VForm) :=
  @sein_modal(VForm).



% Kontrollverben betten den Infinitiv semantisch ein
% und haben ein Subjekt.
control_verb *>
  (synsem:loc:(cat:subcat:(Subcat,
                           hd:arg:loc:(cat:head:(verb,
                                                 subj:hd: @pro_np_ref),
                                       cont:nucleus:VCont)),
               cont:nucleus:(arg1:SubjInd,
                             arg3:VCont)))
  goal last(Subcat,@np_str(SubjInd)).




subj_control_verb *>
  (synsem:loc:cat:subcat:(Subcat,
                          hd:arg:loc:cat:head:subj:hd:arg:loc:cont:nucleus:ind:SubjInd))
  goal last(Subcat,arg:loc:cont:nucleus:ind:SubjInd).


obj_control_verb *>
  (synsem:loc:(cat:subcat:(hd:arg:loc:cat:head:subj:hd:arg:loc:cont:nucleus:ind:ObjInd,
                          append(_,[arg:loc:cont:nucleus:ind:ObjInd,_Subj])),
               cont:nucleus:arg2:ObjInd)).

  
% versuchen, versprechen
% sowohl für kohärente als auch für inkohärente Konstruktion
np_v_subj_zu_inf_control_verb *>
  (%zu_inf_subj_control_verb,
   synsem:loc:cat:subcat:[arg:loc:cat:subcat:Subcat|append(attract_unrealized(Subcat),[@np_str])]).

np_v_subj_control_verb(Relation) :=
  (np_v_subj_zu_inf_control_verb,
   synsem:loc:cont:nucleus:Relation).

np_np_v_subj_zu_inf_control_verb *>
  (%zu_inf_control_verb,
   synsem:loc:(cat:subcat:[arg:loc:cat:subcat:Subcat|append(attract_unrealized(Subcat),[@np,@np_str(SubjInd)])],
               cont:nucleus:arg1:SubjInd)).

% ihm versprechen
np_np_v_subj_control_verb(Case,Relation) :=
  (np_np_v_subj_zu_inf_control_verb,
   synsem:loc:(cat:subcat:[arg:loc:cat:subcat:Subcat|append(attract_unrealized(Subcat),[@np(Case,_ObjInd),_])],
               cont:nucleus:Relation)).

np_np_v_obj_zu_inf_control_verb *>
  (%zu_inf_control_verb,
   synsem:loc:(cat:subcat:[arg:loc:cat:subcat:Subcat|append(attract_unrealized(Subcat),[@np(ObjInd),@np_str])],
               cont:nucleus:arg2:ObjInd)).


% zwingen
np_np_v_obj_control_verb(Relation) :=
  (np_np_v_obj_zu_inf_control_verb,
   synsem:loc:(cat:subcat:[arg:loc:cat:subcat:Subcat|append(attract_unrealized(Subcat),[@np_str,_])],
               cont:nucleus:Relation)).

% erlauben
np_np_v_obj_control_verb(Case,Relation) :=
  (np_np_v_obj_zu_inf_control_verb,
   synsem:loc:(cat:subcat:[arg:loc:cat:subcat:Subcat|append(attract_unrealized(Subcat),[@np(Case,_ObjInd),_])],
               cont:nucleus:Relation)).

% scheinen
coherent_subject_raising_verb(Relation) :=
 (non_flip_coherent_zu_inf_subj_raising_verb,
  synsem:loc:cont:nucleus:Relation).

% beginnen
phase_verb(Relation) :=
 (phase_verb,
  synsem:loc:cont:nucleus:Relation).

% lassen, sehen, hören
aci_verb *>
 (synsem:loc:(cat:subcat:[(arg:loc:cat:(head:subj:Subj,
                                        subcat:Subcat))|append(attract_unrealized(append(Subcat,Subj)),[@np_str(Ind)])],
              cont:nucleus:arg1:Ind)).

aci_verb(Relation) :=
 (aci_verb,
  synsem:loc:cont:nucleus:Relation).


% the same as above but the embedded subject is not raised
% and the DA is required to contain a referential element

%   Dieses Buch läßt hoffen. -> sowohl belebte als auch unbelebte Subjekte möglich
% * Das Buch läßt die Theorie revidieren.
lassen_passive *>
  (synsem:loc:(cat:subcat:[arg:loc:cat:subcat:Subcat|append(raise(Subcat), [@np_str(Ind)])],
               cont:nucleus:(lassen,
                             arg1:Ind))).



preposition_word *>
(%word,
 synsem:loc:(cat:(head:(prep,
                        initial:plus),
                  subcat:[ (@argument_np,
                            arg:nonloc:slash:[]) ] ))).

comp_preposition *>
 (%preposition_word,
  synsem:loc:(cat:(head:case:Cas,
                   subcat:[arg:loc:(cat:head:case:Cas,
                                    cont:Cont) ] ),
              cont:Cont)).

comp_prep(PForm) :=
 (comp_preposition,
  synsem:loc:cat:head:pform:PForm).


n_modifier *>
 synsem:loc:(cat:head:mod: @nbar(Ind),
             cont:nucleus:ind:Ind).

isect_n_modifier *>
(%n_modifier,
 synsem:loc:(cat:head:mod:loc:cont:nucleus:restr:Restr,
             cont:nucleus:restr:tl:Restr)).


modifier_le *>
 (%lexical_sign
  synsem:loc:(cat:(head:mod:loc:cont:qstore:Q,
                   subcat:Subcat),
              cont:qstore:append(Q,collectQStores(Subcat)))).
     
adj_stem *>
 (%n_modifier,
  synsem:loc:cat:head:adj).


% Nicht alle Adjektive haben ein Subjekt (mir ist warm)
isect_adj *>
 (%adj_stem
  synsem:loc:(cat:head:(adj,
                        subj:[@np(Ind)]),
              cont:nucleus:arg2:Ind)).



% klug
%simple_adj *>
  %intersective_adj sc_complete_le

adj(Relation) :=
 (simple_adj,
  synsem:loc:cont:nucleus:Relation).



% treu
np_adj *>
 (%intersective_adj
  synsem:loc:(cat:subcat:[@np(Ind2)],
              cont:nucleus:arg3:Ind2)).
 
np_adj(Relation,GCase) :=
 (np_adj,
  synsem:loc:(cat:subcat:[@np(GCase,_Ind2)],
              cont:nucleus:Relation)).


pp_adj *>
 (%intersective_adj
  synsem:loc:(cat:subcat:[@pp(Ind2)],
              cont:nucleus:arg3:Ind2)).

pp_adj(Relation,PForm,Case) :=
 (pp_adj,
  synsem:loc:(cat:subcat:[@pp(PForm,Case)],
              cont:nucleus:Relation)).

% mutmaßlich
scopal_adj *>
 synsem:loc:(cat:head:mod:loc:cont:nucleus:restr:Restr,
             cont:nucleus:psoa_arg:Restr).

scopal_adj(Relation) :=
 (scopal_adj,
  synsem:loc:cont:nucleus:Relation).


mod_preposition *>
 (%preposition_word,
  synsem:loc:cat:head:mod_prep).



noun_mod_preposition *>
 (%mod_preposition
  %isect_n_modifier_word
  synsem:loc:(cat:(head:(pre_modifier:minus,
                         mod:loc:cont:nucleus:ind:Ind),
                   subcat:[ @np(Ind2) ] ),
              cont:nucleus:(ind:Ind,
                            restr:hd:(arg3:Ind,
                                      arg2:Ind2)))).
 
location_noun_mod_prep *>
 (%noun_mod_preposition
  synsem:loc:cat:subcat:[ @np(dat,_) ] ).

location_noun_mod_prep(Relation) :=
 (location_noun_mod_prep,
  synsem:loc:cont:nucleus:restr:hd:Relation).




v_modifier_word *>
  (%overt_spr_saturated_non_rel_word
   synsem:loc:cat:head:(pre_modifier:plus,
                        mod:loc:cat:head:(participle_or_verb,
                                          initial:minus))).

isect_v_modifier_word *>
  (%v_modifier_word,
   synsem:loc:(cat:head:mod:loc:cont:nucleus:(%main_rel,        % Keine Hilfsverben, funktioniert nicht, wegen Tempus-Semantik
                                              Cont),
               cont:nucleus:(und,
                             arg1:Cont,
                             arg2:arg3:Cont))).

scopal_v_modifier_word *>
 (%v_modifier_word,
  synsem:loc:(cat:head:mod:loc:cont:nucleus:Cont,
              cont:nucleus:arg3:Cont)).


adverb_word *>
 (%v_modifier_word
  synsem:loc:cat:head:adv).


scopal_adv(Relation) :=
 (scopal_adverb,
  synsem:loc:cont:nucleus:Relation).


intersect_adv(Relation) :=
 (intersective_adverb,
  synsem:loc:cont:nucleus:arg2:Relation).

temp_adv(Relation) :=
  @intersect_adv(Relation).


verb_mod_preposition *>
  synsem:loc:(cat:subcat:[ @np(Ind2) ],
              cont:nucleus:arg2:arg2:Ind2).

location_verb_mod_prep *>
  synsem:loc:cat:subcat:[ @np(dat,_Ind2) ].

location_verb_mod_prep(Relation) :=
 (location_verb_mod_prep,
  synsem:loc:cont:nucleus:arg2:Relation).


% Nur Partizipien haben ein Element in DA. Echte Adjektive haben eine
% leere DA-Liste.
passive_preposition *>
  (%mod_preposition
   synsem:loc:(cat:(head:mod:loc:(cat:head:da:[ @blocked_np_ref(Ind) ],
                                  cont:nucleus:Cont),
                           
                     subcat:[ @np(dat,Ind) ]),
               cont:nucleus:Cont)).


% Komplementierer und das Verb in Erststellung
complementizer_like_word *>
 (%spr_saturated_sc_incomplete_word
  synsem:loc:(cat:(head:(dsl:none,
                         initial:plus),
                   subcat:[ (@argument,
                             arg:(loc:(cat:(head:(verb,
                                                  vform:fin,
                                                  initial:minus),
                                            subcat:list_of_spirits),
                                       cont:(nucleus:Nuc,
                                             qstore:QStore)),
                                  trace:minus)) ]),
              cont:(nucleus:arg3:Nuc,
                    qstore:QStore))).

complementizer_word *> 
 (%spr_saturated_sc_incomplete_word
  %complementizer_like_word
  synsem:loc:(cat:(head:comp,
                   subcat:hd:arg:loc:cat:head:dsl:none),
              cont:nucleus:assertion)).


complementizer(CForm) :=
 (complementizer_word,
  synsem:loc:cat:head:cform:CForm).









