% -*-trale-prolog-*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: lexrules.pl,v $
%%  $Revision: 1.11 $
%%      $Date: 2006/08/21 15:50:14 $
%%     Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%%    Purpose: Eine kleine Spielzeuggrammatik für die Lehre
%%   Language: Trale
%      System: TRALE 2.7.5 (release ) under Sicstus 3.12.0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

:- multifile if/2.
:- discontiguous if/2.
:- multifile fun/1.
:- discontiguous fun/1.
:- multifile ':='/2.
:- discontiguous ':='/2.
:- multifile lex_rule/2.
:- discontiguous lex_rule/2.
:- multifile '*>'/2.
:- discontiguous '*>'/2.

:- lex_rule_depth(5).



verb_movement_lr *>
( %complex_word
  %optionally_coherent_word
  synsem:(loc:cat:(head:(verb,
                         subj:raise(Subj)),
                   subcat:hd:arg:loc:cat:head:dsl:Loc),
          nonloc:Nonloc,
          trace:Trace,
          lex:Lex),
  zu:Zu,
  dtrs:[( word,
          synsem:(loc:(Loc,
                       cat:head:(verb,
                                 subj:Subj,
                                 initial:minus)),
                  nonloc:Nonloc,
                  trace:Trace,
                  lex:Lex),
          zu:Zu)]).


verb_initial_lr *>
( %verb_movement_lr
  %complementizer_like_word
  synsem:loc:cat:head:(vform:fin,
                       subj:[]),
  dtrs:[ synsem:loc:cat:(head:vform:fin,
                         subcat:list_of_non_raised_arguments) ]).


% Sätze mit Verb in Erststellung können Imperativsätze oder auch Interrogativsätze sein.
% Die beiden folgenden Sätze unterscheiden sich nur hinsichtlich ihrer Flexion:
%
%     Gib   Du mir das Buch!
%     Gibst Du mir das Buch?
%
% Die genaue Auflösung der Relation erfolgt erst in der Grammatik für Kapitel 16,
% da dort erst eine Morphologiekomponente eingeführt wird.

% Konditionalsätze werden ignoriert.

(verb_initial_lr,
 synsem:loc:cat:subcat:[arg:nonloc:slash:[]])      *> synsem:loc:cont:nucleus:imperative_or_interrogative.

% Hier spielt das Element in SLASH eine entscheidende Rolle.
% Ist es eine Interrogativphrase, muß ein entsprechender Operator angenommen
% werden. Da die vorliegende Grammatik keine Interrogativpronomina enthält,
% wird die Fallunterscheidung nicht gemacht.

% Er gibt ihm das Buch.
% Jetzt gib mir schon das Buch!
(verb_initial_lr,
 synsem:loc:cat:subcat:[arg:nonloc:slash:ne_list]) *> synsem:loc:cont:nucleus:assertion_or_imperative.

% pres_imp = imp in der kombinerten Tense-Modus-Hierarchie
(s_type,
 arg3:pres_imp) *> imperative.

(s_type,
 arg3:ind_conj) *> assertion_or_interrogative.



verb_initial_lr ##
  Dtr
**>
( verb_initial_lr,
  dtrs:[Dtr])
morphs
  X becomes X.


reg_infl_lr *>
 ( % head_cluster_word
   head_dtr:(Suffix,
               infl_suffix),
   non_head_dtrs:[(Stem,
                   stem)],
   dtrs:[Stem,Suffix]).


% Nomina und Verben haben morphophonologische Merkmale,
% die mit dem Affix übereinstimmen müssen.
n_v_infl_lr *>
  (%reg_infl_lr,
   dtrs:[infl:(fk:FK,
               morphophon:Morphophon),(fk:FK,
                                       morphophon:Morphophon)]).


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Flexionsregel für finite Verben


fin_verb_infl_lr *>
( %complex_word,
  synsem:(nonloc:Nonloc,
          lex:Lex,
          trace:Trace),
  zu:minus,
  dtrs:hd:( stem,
            synsem:(nonloc:Nonloc,
                    lex:Lex,
                    trace:Trace))).



reg_fin_verb_infl_lr *>
( %fin_verb_infl_lr
  dtrs:[ infl:affix_:Affix,
         (Affix,
          fin_verb_i_suffix)]).

% bei irregulären Formen gibt es kein Affix.
% Die Arbeit des Affixes wird in der Regel erledigt.
irreg_fin_verb_infl_lr *>
 (phon:Phon,
  synsem:(loc:(cat:(Cat,
                    head:(initial:minus,
                          subj:[],
                          vform:fin)),
               cont:(nucleus:arg3:Cont,
                     qstore:QStore)),
          nonloc:Nonloc,
          lex:Lex,
          trace:Trace),
  dtrs:[(phon:Phon,
         synsem:(loc:(cat:Cat,
                      cont:(nucleus:Cont,
                            qstore:QStore)),
                 nonloc:Nonloc,
                 lex:Lex,
                 trace:Trace))]).


fin_verb_infl_lr ##
( stem,
  infl:(v_stems:VStems,
        affix_:(Affix,
                fin_verb_i_suffix)),          % Das muß hier auch maximal spezifisch sein, da die Typinferenz, die
                                              % aus dem Vorhandensein von NUM und PER auf die Finitheit schließt,
                                              % erst angewendet wird, wenn die linke Regelseite angeguckt wird.
  Dtr
) 
 **>
( reg_fin_verb_infl_lr,
  zu:minus,
  dtrs:[Dtr,phon:[a_ AffixPhon]]
  )
if get_irreg_v_stem(Affix,VStems,a_ IStem)
morphs
  X becomes (X,AffixPhon) when IStem = none,
  X becomes (IStem,AffixPhon).


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Flexionsregel für Infinitive
% Das Subjekt wird aus der SUBCAT-Liste genommen
% und unter SUBJ repräsentiert.

bse_or_inf_verb_infl_lr *>
 (%complex_word
  synsem:(loc:(cat:(head:(Head,
                          verb,
                          initial:minus,
                          subj:Subj),
                    spr:Spr,
                    subcat:block_subject(Subcat,Subj)),
               cont:Cont),
          nonloc:Nonloc,
          lex:Lex,
          trace:Trace),
  dtrs:[(stem,
         synsem:(loc:(cat:(head:Head,
                           spr:Spr,
                           subcat:Subcat),
                      cont:Cont),
                 nonloc:Nonloc,
                 lex:Lex,
                 trace:Trace)) ]).

reg_bse_or_inf_verb_infl_lr *>
 (%bse_or_inf_verb_infl_lr,
  %n_v_infl_lr,
  dtrs:tl:hd:bse_verb_i_suffix).

bse_verb_infl_lr *>
 (%bse_or_inf_verb_infl_lr
  synsem:loc:cat:head:vform:bse,
  zu:minus).

% Infinitive sind fast identisch. Das Ergebniszeichen ist aber vom
% Type zu_word. Dieser kann in keiner Grammatikregel vorkommen, außer
% in einer Regel, die `zu' mit dem Wort kombiniert.
inf_verb_infl_lr *>
 (%bse_or_inf_verb_infl_lr
  synsem:loc:cat:head:vform:inf,
  zu:plus).



bse_verb_infl_lr ##
  Dtr
 **>
( reg_bse_verb_infl_lr,
  dtrs:[Dtr,phon:[a_ AffixPhon]]
)
morphs
  X becomes (X,AffixPhon).


inf_verb_infl_lr ##
  Dtr
 **>
( reg_inf_verb_infl_lr,
  dtrs:[Dtr,phon:[(a_ AffixPhon)]])
morphs
  X becomes (X,AffixPhon).





ppp_verb_infl_lr *>
( %complex_word,
  synsem:(loc:(cat:(head:(Head,
                          verb,
                          vform:ppp,
                          initial:minus,
                          subj:DA,
                          flip:minus % except modal verbs, not covered yet
                         ),
                    subcat:block_da(DA,Subcat)),
              cont:Cont),
          nonloc:Nonloc,
          lex:Lex,
          trace:Trace),
  zu:minus,
  dtrs:[(stem,
         synsem:(loc:(cat:(head:(Head,
                                 da:DA),
                           subcat:Subcat),
                      cont:Cont),
                 nonloc:Nonloc,
                 lex:Lex,
                 trace:Trace))]).

reg_ppp_verb_infl_lr *>
  dtrs:tl:hd:ppp_verb_i_suffix.
        
ppp_verb_infl_lr ##
  (infl:(v_stems:part:(a_ IStem),
         bet1:Bet),
   Dtr)
  **>
( reg_ppp_verb_infl_lr,
  dtrs:tl:hd:phon:[(a_ Suff)],
  dtrs:[Dtr])
if
   (get_prefix(Bet,Ge),
    Ge=(a_ GeP))
morphs
  X becomes (GeP,X,Suff) when IStem = none,
  X becomes (GeP,IStem,Suff).

fun list_of_blocked_arguments(-).
list_of_blocked_arguments(L) if
   when( (L=(e_list;ne_list)),
         undelayed_list_of_blocked_arguments(L) ).

undelayed_list_of_blocked_arguments([]) if true.
undelayed_list_of_blocked_arguments([@blocked_np_ref|T]) if
   list_of_blocked_arguments(T).


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Pränominale Partizipien (`geliebte' und `zu lesende')
%
%
%
part_derivation_lr *>
 (stem,
  synsem:(loc:cat:(head:(attr_participle,         % kann nicht prädikativ genutzt werden,
                                                  % dafür sollte es eine prinzipiellere Erklärung geben.
                         subj:raise([Subj]),
                         da:(DA,
                             list_of_blocked_arguments)),
                   subcat:raise(Subcat)),
          nonloc:Nonloc,
          lex:Lex,
          trace:Trace),
  zu:Zu,
  dtrs:[(word,
         synsem:(loc:cat:(head:(verb,
                                da:DA,
                                flip:minus      % schließt Ersatzinfinitive aus * `wollene' statt `gewollte'
                               ),    
                          subcat:append(Subcat,[(Subj,@np_str)])),
                 nonloc:Nonloc,
                 lex:Lex,
                 trace:Trace),
         zu:Zu,
         % Dies ist ein Hack, der unechte Mehrdeutigkeiten für `angelachte' und `anzulachende' ausschließt.
         % Ohne diese Beschränkung kann die Partikel mit dem Verb kombiniert werden, bevor die Derivation
         % angewendet wird. Dies läßt sich nicht ohne weiteres ausschließen, da man die entsprechende
         % Partizipform für `Sie hat ihn angelacht.' braucht. Allerdings braucht man nach der Derivation
         % auch eine syntaktische Komplexbildung mit Verben und Resultativpräsikaten:
         %
         % die sturmreif geschossene Stadt (aber auch: das plattgefahrene Tier)
         % der schlafen wollende Mann
         %
         % Die Beschränkung funktioniert nur, weil die Affixe nicht in den Tochterlisten verwaltet werden.
         dtrs:[_])]).


% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%
% %% Partizip II
% %
% % geliebt (V) -> geliebt (A)
% %
% % Flexionsregel erzeugt dann: geliebt (A) -> geliebte
% %
% ppp_part_derivation_lr *>
%  (synsem:loc:cont:Cont,
%   zu:Zu,
%   dtrs:[ (synsem:loc:(cat:head:vform:ppp,
%                       cont:Cont),
%           zu:Zu)]).

% ppp_part_derivation_lr ##
%   Dtr
%  **>
% ( ppp_part_derivation_lr,
%   dtrs:[Dtr]
%   )
% morphs
%   X becomes X.

% % * der zu gelingende Aufsatz
% % der zu lesende Aufsatz
% inf_part_derivation_lr *>
%  (synsem:loc:cont:(qstore:QStore,
%                    nucleus:(modal_rel,
%                             arg3:VCont)),
%   dtrs:[synsem:loc:(cat:head:vform:inf,
%                     cont:(qstore:QStore,
%                           nucleus:VCont))]).


% inf_part_derivation_lr ##
%   Dtr
%  **>
% ( inf_part_derivation_lr,
%   dtrs:[Dtr]
%   )
% morphs
%   X becomes (X,d).

% % lesen -> lesend
% bse_part_derivation_lr *>
% (synsem:(loc:(cat:(head:(attr_participle,
%                          subj:[Subj],
%                          da:(DA,
%                              list_of_blocked_arguments)),
%                    subcat:Subcat),
%               cont:VCont),
%          nonloc:Nonloc,
%          lex:Lex,
%          trace:Trace),
%  zu:Zu,
%  dtrs:[(word,
%         synsem:(loc:(cat:(head:(verb,
%                                 vform:bse,
%                                 subj:[Subj],
%                                 da:DA),
%                           subcat:Subcat),
%                      cont:VCont),
%                 nonloc:Nonloc,
%                 lex:Lex,
%                 trace:Trace),
%         zu:Zu)]).

% bse_part_derivation_lr ##
%   Dtr
%  **>
% ( bse_part_derivation_lr,
%   dtrs:[Dtr]
%   )
% morphs
%   X becomes (X,d).


% non_move_synsem :=
%   (nonloc:(slash:[],
%            rel:[])).

% fun list_of_non_move_arguments(-).
% list_of_non_move_arguments(L) if
%    when( (L=(e_list;ne_list)),
%          undelayed_list_of_non_move_arguments(L) ).

% undelayed_list_of_non_move_arguments([]) if true.
% undelayed_list_of_non_move_arguments([arg: @non_move_synsem|T]) if
%    list_of_non_move_arguments(T).


% attr_adj_infl_lr *>
% (synsem:(loc:cat:(head:(Head,
%                         mod:loc:cat:spr:[loc:cat:head:(case:morph_case:Case,
%                                                        gen:Genus,
%                                                        num:Num,
%                                                        dtype:DType)]),
%                   subcat:(Subcat,
%                           list_of_non_raised_arguments,
%                           list_of_non_move_arguments)), % aus dem pränominalen Bereich kann nichts extrahiert werden
%                                                         % Relativpronomina sind hier ebenfalls nicht möglich.
%          nonloc:Nonloc,
%          lex:Lex,
%          trace:Trace),
%  zu:Zu,
%  dtrs:[(synsem:(loc:cat:(head:Head,
%                          subcat:Subcat),
%                 nonloc:Nonloc,
%                 lex:Lex,
%                 trace:Trace),
%         zu:Zu),
%        (attr_adj_i_suffix,
%         dtype:DType,
%         num:Num,
%         gen:Genus,
%         morph_case:Case)]).


% attr_adj_infl_lr *>
%  synsem:loc:cat:head:(subj:[ @pro_np(Ind) ],
%                       mod:loc:cont:nucleus:ind:Ind).


% isect_attr_adj_infl_lr *>
%   (synsem:loc:cont:nucleus:restr:hd:Cont,
%    dtrs:[synsem:loc:cont:nucleus:(non_psoa_rel,  % ginge auch mit @not(psoa_rel)
%                                                  % aber wegen der Partikelverben ist der negierte Typ nötig.
%                                   Cont)]).
      

% % prädikative Adjektive sind in dieser Grammatik nicht implementiert.
% isect_attr_adj_infl_lr ##
%  Dtr
% **>
% (%@isect_attr_adj_or_participle_word,
%  isect_attr_adj_infl_lr,
%  dtrs:[Dtr,phon:[(a_ Suffix)]])
% morphs
%   X becomes (X,Suffix).

% scopal_attr_adj_infl_lr *>
%   (synsem:loc:cont:nucleus:restr:[Cont],
%    dtrs:[synsem:loc:cont:nucleus:(psoa_rel,
%                                   Cont)]).

% scopal_attr_adj_infl_lr ##
%  Dtr
% **>
% (%@general_attr_adj_or_participle_word,
%  scopal_attr_adj_infl_lr,
%  dtrs:[Dtr,phon:[(a_ Suffix)]])
% morphs
%   X becomes (X,Suffix).



% prd_adj_infl_lr *>
% (%complex_word,
%  synsem:(loc:(cat:(head:(Head,
%                          mod:none,
%                          prd:plus),
%                    subcat:Subcat),
%               cont:Cont),
%          nonloc:Nonloc,
%          lex:Lex,
%          trace:Trace),
%  zu:Zu,
%  dtrs:[(stem,
%         synsem:(loc:(cat:(head:(Head,
%                                 adj),
%                           subcat:Subcat),
%                      cont:Cont),
%                 nonloc:Nonloc,
%                 lex:Lex,
%                 trace:Trace),
%         zu:Zu)]
%  ).

% prd_adj_infl_lr ##
%   Dtr
%  **>
% ( prd_adj_infl_lr,
%   dtrs:[Dtr])
% morphs
%   X becomes X.



% transparent_particle_verb_lr *>
% (%stem,
%  synsem:(loc:(cat:(head:Head,
%                    subcat:[(@argument,
%                            arg:
%                            (loc:(cat:(head:(part,
%                                             subj:ParticleSubj,
%                                             mod:InputSynsem),
%                                       subcat:ParticleSubcat),
%                                  cont:ParticleCont),
%                             lex:plus))
%                           |append(append(ParticleSubcat,ParticleSubj),InputSubcat)]),
%               cont:(ParticleCont,
%                     nucleus:non_psoa_rel)),        % Diese Beschränkung ist nur aus technischen Gründen hier.
%                                        % Sie sorgt dafür, daß die Adjektivflexionsregel für skopale
%                                        % Adjektive nicht angewendet wird. Die Information über den
%                                        % semantischen Beitrag ist in der Grammatik erst nach der Kombination
%                                        % mit der Verbpartikel bekannt, aber das Adjektiv wird vorher gebildet,
%                                        % ohne mit irgendwelchen Partikeln kompatibel zu sein, ist also unnütz.
%                                        %
%                                        % Das Laden hat sich von 3 min 11 sec auf  2 min 38 sec verkürzt.
%                                        % Statt 3410 Lexikoneinheiten wurden nur 3298 erzeugt.
        
%          nonloc:Nonloc,
%          lex:Lex,
%          trace:Trace),
%  zu:Zu,
%  infl:Infl,
%  dtrs:[(stem,
%         synsem:(InputSynsem,
%                 loc:cat:(head:(Head,
%                                verb),
%     %                           subj:[]),           % Der Verbstamm wird modifiziert.
%                                                    % Ohne diese Beschränkung, bliebe der SUBJ-Wert uninstantiiert ->
%                                                    % Residuen bzw. mehrere Modelle bei Auflösung der Werte.
%                          subcat:(InputSubcat,
%                                  [arg:lex:minus])  % Das schränkt die Eingabe auf intransitive Verben ein.
%                                                    % Diese Beschränkung ist linguistisch nicht nötig, da
%                                                    % sie außerdem von den Partikeln (MOD) kommt. Ohne diese
%                                                    % Beschränkung wird allerdings unnötig ein riesiges Lexikon erzeugt.
%                         ),
%                 nonloc:Nonloc,
%                 lex:Lex,
%                 trace:Trace),
%         zu:Zu,
%         infl:Infl)]
%  ).



% transparent_particle_verb_lr ##
%   Dtr
%  **>
% ( transparent_particle_verb_lr,
%   dtrs:[Dtr])
% morphs
%   X becomes X.



% % Die Analyse der Partikelverben so, wie sie im Buch beschrieben ist,
% % sieht vor, daß der Verbstamm flektiert und erst danach mit der Partikel
% % kombiniert wird. Da es Lexikoneinträge für Partikeln gibt und da
% % Trale keine eigene Morphologiekomponente hat, die eine Kombination
% % von Wörtern zu neuen Wörtern erlaubt, muß man die Kombination mit
% % Lexikonregeln nachbauen, die die Information der Lexikoneinträge
% % für die Partikel einschließen.
% % Dazu wird der lexikalische Typ der ersten Tochter spezifiziert (particle).
% % Für diesen Typ gibt es eine disjunktive Spezifikation aller Verbpartikel
% % (siehe lexicon.pl).

% % Die Kombination kann nicht vom Typ head_cluster_phrase sein, da die
% % Töchter von Phrasen in Bezug auf `zu' vollständig sein müssen.
% % Das ist aber für Fälle wie `anzulachen' nicht gegeben, denn das `zu'
% % wird durch die Lexikonregel eingeführt.

% % Eigentlich sollte cluster_word ein Untertyp von cluster_structure sein,
% % aber aus irgendwelchen Gründen, die ich nicht durchschaue, interagiert
% % das mit der bar-Derivations-LR und Trale hängt sich auf.


% % Da die Lexikonregel die Arbeit eines Schemas übernimmt, muß sie
% % auch die Ergebnisse von Beschränkungen einbauen, die für Schemata gelten
% % würden. Dazu zählt die Spezifikation des DSL-Werts bei phonologisch gefüllten
% % Töchtern.

% particle_head_word *>
% (%head_cluster_word,
%  synsem:(loc:(cat:(head:Head,
%                    spr:Spr,
%                    subcat:[(raised:Raised,
%                             realized:plus,
%                             arg:Arg)|Subcat]),
%               cont:Cont),
%          nonloc:Nonloc,
%          lex:Lex,
%          trace:Trace),
%  dtrs:[(particle,
%         synsem:Arg),
%        (word,
%         synsem:(loc:(cat:(head:(Head,
%                                 dsl:none),
%                           spr:Spr,
%                           subcat:[(raised:Raised,
%                                    realized:minus,
%                                    arg:Arg)|Subcat]), % Das erste Element ist die Partikel. Das wird abgebunden.
%                      cont:Cont),
%                 nonloc:Nonloc,
%                 lex:Lex,
%                 trace:Trace))]
% ).


% /*
% % für fin-, bse- und ppp-Formen = anlachst, anlachen, gelacht
% % für Adjektive und Nomina
% particle_head_word_fin_bse_ppp_lr ##
%  (zu:(Zu,
%       minus),
%   Dtr)
% **>
% (particle_head_word,
%  dtrs:[phon:[a_ ParticlePhon],
%        Dtr],
%  zu:Zu)
% morphs
%   X becomes (ParticlePhon,X).


% % für inf-Formen = anzulachen
% particle_head_word_inf_lr_hack ##
%  (zu:plus,
%   Dtr)
% **>
% (particle_head_word,
%  dtrs:[phon:[a_ ParticlePhon],
%        Dtr],
%  zu:minus)
% morphs
%   X becomes (ParticlePhon,zu,X).
% */


% bar_derivation_lr *>
% (synsem:(loc:(cat:(head:(adj,
%                          subj:[Obj]),
%                    subcat:Rest),
%               cont:(qstore:QStore,
%                     nucleus:(modal_rel,
%                              arg3:VCont))),
%          nonloc:Nonloc,
%          lex:Lex,
%          trace:Trace),
%  zu:minus,
%  dtrs:[(stem,
%         synsem:(loc:(cat:(head:(verb,
%                                 subj:[],              % Der Verbstamm wird modifiziert.
%                                                       % Ohne diese Beschränkung, bliebe der SUBJ-Wert uninstantiiert ->
%                                                       % Residuen bzw. mehrere Modelle bei Auflösung der Werte.
%                                 da:[@blocked_np_ref]),
%                           subcat:(append(Rest,[(Obj,
%                                                 @np_str),@pro_np(_Ind)]),
%                                   hd:arg:loc:cat:head: @not(verb))             % *zwingbar, *versuchbar, *erlaubbar
%                          ),
%                      cont:(qstore:QStore,
%                            nucleus:(%main_rel,  % schließt `habbar' und `bekommbar' aus
%                                     % muß noch gefixt werden, gegenwärtig inkompatibel mit
%                                     % non_psoa_rel
%                                     VCont))),
%                      nonloc:Nonloc,
%                      lex:Lex,
%                      trace:Trace),
%         % Diese Spezifikation ist unschön! Sie schließt nur unechte Mehrdeutigkeiten aus.
%         % Sie sollte durche eine Änderung der Merkmalsgeometrie unnötig gemacht werden.
%         infl:affix_:unused)]).



% bar_derivation_lr ##
%   Dtr
%  **>
% ( bar_derivation_lr,
%   dtrs:[Dtr])
% morphs
%   X becomes (X,bar).


% noun_infl_lr *>
% (synsem:(Synsem,
%          loc:(cat:head:case:morph_case:Case,
%               cont:nucleus:ind:num:Num)),
%  zu:Zu,
%  dtrs:[(stem,
%         synsem:(Synsem,
%                 loc:cat:head:noun),
%         zu:Zu,
%         infl:noun_infl),
%        (noun_i_suffix,
%         num:Num,
%         morph_case:Case)]).


% % If `Dtr' is placed before `infl' we get an instantiation error.
% % This is defeinitely a Trale-Bug. 19.08.06
% noun_infl_lr ##
%   (infl:umlaut:UmlautStem,
%    Dtr)
%  **>
% ( noun_infl_lr,
%   dtrs:[Dtr,(noun_i_suffix,                 % siehe oben
%              num:Num,
%              phon:[a_ Suff])])
%  if
%    (%prolog(format("~w ~w~n", [Num,Suff])),
%    get_irreg_n_stem(Num,UmlautStem,(a_ IStem)))
% morphs
%   X becomes (X,Suff) when IStem = none,
%   X becomes (IStem,Suff).

% % Beamter, Gesandter
% adj_noun_infl_lr *>
% (synsem:(Synsem,
%          loc:cat:spr:[loc:cat:head:(case:morph_case:Case,
%                                     gen:Genus,
%                                     num:Num,
%                                     dtype:DType)]),
%  zu:Zu,
%  dtrs:[(synsem:(Synsem,
%                 loc:cat:head:noun),
%         zu:Zu,
%         infl:adj_infl),
%        (attr_adj_i_suffix,
%         dtype:DType,
%         num:Num,
%         gen:Genus,
%         morph_case:Case)]).


% adj_noun_infl_lr ##
%   Dtr
%  **>
% ( adj_noun_infl_lr,
%   dtrs:[Dtr],phon:[(a_ Suffix)])
% morphs
%   X becomes (X,Suffix).


% ge_e_nominalization_lr *>
% (%derived_stem,
%  %det_noun,
%  %noun_nominal
%  synsem:(loc:(cat:(head:noun,
%                     spr:[loc:cont:qstore:DetQStore],
%                     subcat:(ClusterParts,
%                             list_of_non_move_arguments)), % Left Branch Condition, Extraktion der Partikel ist
%                                                           % in der Nominalphrase natürlich nicht möglich.
%                                                           % Das sollte irgendwo prinzipiell geregelt sein.
%                cont:(qstore:append(DetQStore,VerbQStore),
%                      nucleus:(ind:(num:sg,
%                                    gen:neu),
%                               restr:[(repeated_event,
%                                       arg3:VCont)]))),
%           nonloc:Nonloc,
%           lex:Lex,
%           trace:Trace),
%  zu:minus,
%  infl:(fk:nfk_1,
%        morphophon:gen_e:minus),
%  dtrs:[(stem,
%         synsem:(loc:(cat:(head:verb,
%                           subcat:append((ClusterParts,
%                                     list_of_complex_forming_arguments),
%                                    (list_of_non_complex_forming_arguments,
%                                     list_of_blocked_arguments))),
%                      cont:(qstore:VerbQStore,
%                            nucleus:VCont)),
%                 nonloc:Nonloc,
%                 lex:Lex,
%                 trace:Trace),
%         % Diese Spezifikation ist unschön! Sie schließt nur unechte Mehrdeutigkeiten aus.
%         % Sie sollte durche eine Änderung der Merkmalsgeometrie unnötig gemacht werden.
%         infl:affix_:unused
%         )]).


% ge_e_nominalization_lr ##
%   Dtr
%  **>
% ( ge_e_nominalization_lr,
%   dtrs:[Dtr])
% morphs
%   X becomes (ge,X,e).



% Im Prinzip ist das eine Liste von LEX+-Elementen, aber das
% würde ein zu großes Lexikon erzeugen, das Lexikoneinträge enthält,
% die wegen syntaktischer Prinzipien nie genutzt werden würden.
% Für die hier interessierenden Fälle sind nur die Partikeln interessant,
% also wird eine Einschränkung auf die Wortart vorgenommen.
fun list_of_complex_forming_arguments(-).
list_of_complex_forming_arguments(L) if
   when( (L=(e_list;ne_list)),
         undelayed_list_of_complex_forming_arguments(L) ).

undelayed_list_of_complex_forming_arguments([]) if true.
undelayed_list_of_complex_forming_arguments([arg:loc:cat:head:part|T]) if     %([arg:lex:plus|T]) if
   list_of_complex_forming_arguments(T).



get_prefix(plus, (a_ [g,e])) if true.
get_prefix(minus,(a_ [])   ) if true.


det_infl_lr *>
  (synsem:(Synsem,
           loc:cat:head:(det,
                         num:Num,
                         gen:Gen,
                         case:morph_case:Case,
                         dtype:DType)),
   dtrs:[(stem,
          synsem:Synsem),
         (det_i_suffix,
          num:Num,
          gen:Gen,
          morph_case:Case,
          dtype:DType)]).
          


% sharing of declension class is done in the macros for lexical entries
% in cases like `ein' in which we have mixed declension the value from the suffix is ignored
det_infl_lr ##
 Dtr
**>
(det_infl_lr,
 dtrs:[Dtr,phon:[a_ Suff]])
morphs
  X becomes (X,Suff).



get_irreg_v_stem((Affix,
                  phon:Phon),VStems,IrregStem) if
  when(Phon=(e_list;ne_list)
       ,undelayed_get_irreg_v_stem(Affix,VStems,IrregStem)).


undelayed_get_irreg_v_stem((synsem:loc:cont:nucleus:pres_ind_conj),                (pres2:(a_ none)),     (a_ none    ))  if !,true.

% ich fange, du fängst, er fängt
% ich habe, du hast, er hat
undelayed_get_irreg_v_stem((fk:(v_strong;mixed;v_weak),
                            synsem:loc:cont:nucleus:pres_ind, per:second_or_third,num:sg),(pres2:(a_ Pres2Stem)),(a_ Pres2Stem)) if !,true.


undelayed_get_irreg_v_stem((fk:(v_strong;mixed;v_weak),
                            synsem:loc:cont:nucleus:pres_imp),                     (imp_st:(a_ Pres2Stem)),(a_ Pres2Stem)) if !,true.

% Ich darf, du darfst, er darf, wir dürfen, ihr dürft, sie dürfen
% the irregular stem in sg:
undelayed_get_irreg_v_stem((fk:modal,
                            synsem:loc:cont:nucleus:pres_ind,
                            num:sg),                            (pres2:(a_ Pres2Stem)),(a_ Pres2Stem)) if !,true.


undelayed_get_irreg_v_stem((synsem:loc:cont:nucleus:pres_conj,per:second_or_third,num:sg),_,     (a_ none    ))  if !,true.

% ich fange, ich habe
undelayed_get_irreg_v_stem((fk:(v_strong;mixed),
                            synsem:loc:cont:nucleus:pres_ind_conj,per:first,num:sg),      _,                     (a_ none    ))  if !,true.


% versuchtest
undelayed_get_irreg_v_stem((synsem:loc:cont:nucleus:past_ind_conj),                (past:(a_ none),
                                                                 conj:(a_ none)),      (a_ none    ))  if !,true.

% ich fing, ..., ich durfte, ...
undelayed_get_irreg_v_stem((synsem:loc:cont:nucleus:past_ind),                     (past:(a_ PastStem)),  (a_ PastStem))  if !,true.

% If a conj stem is definied, take it, otherwise return the past stem.
% kommen, kam, käme
% fangen, fing, finge
undelayed_get_irreg_v_stem((synsem:loc:cont:nucleus:past_conj),                    (conj:(a_ ConjStem)),  (a_ ConjStem))  if !,prolog(ConjStem\=none).
undelayed_get_irreg_v_stem((synsem:loc:cont:nucleus:past_conj),                    (past:(a_ ConjStem)),  (a_ ConjStem))  if !,prolog(ConjStem=none).


undelayed_get_irreg_v_stem(_,          _,                     (a_ none    ))  if true.

